pub struct EncryptedPrivateKeyInfo<Data> {
pub encryption_algorithm: EncryptionScheme,
pub encrypted_data: Data,
}Available on crate feature
pkcs5 only.Expand description
PKCS#8 EncryptedPrivateKeyInfo.
ASN.1 structure containing a PKCS#5 EncryptionScheme identifier for a
password-based symmetric encryption scheme and encrypted private key data.
Schema
Structure described in RFC 5208 Section 6:
EncryptedPrivateKeyInfo ::= SEQUENCE {
encryptionAlgorithm EncryptionAlgorithmIdentifier,
encryptedData EncryptedData }
EncryptionAlgorithmIdentifier ::= AlgorithmIdentifier
EncryptedData ::= OCTET STRINGFields
encryption_algorithm: EncryptionSchemeAlgorithm identifier describing a password-based symmetric encryption
scheme used to encrypt the encrypted_data field.
encrypted_data: DataPrivate key data
Implementations
Sourceimpl<'a, Data> EncryptedPrivateKeyInfo<Data>
impl<'a, Data> EncryptedPrivateKeyInfo<Data>
Sourcepub fn decrypt(&self, password: impl AsRef<[u8]>) -> Result<SecretDocument>
Available on crate feature encryption only.
pub fn decrypt(&self, password: impl AsRef<[u8]>) -> Result<SecretDocument>
encryption only.Attempt to decrypt this encrypted private key using the provided password to derive an encryption key.
Errors
- Returns errors in the event the file could not be decrypted successfully.
- Returns errors if the file decrypted but the resulting plaintext failed to decode.